@@ -365,7 +365,7 @@ public class GmailSendTransport extends MailTransport {
         // Verify that the account has an access token
         if (Strings.isEmpty(account.getToken())) {
             API api = account.getAPI();
-            throw OAuthExceptionCodes.OAUTH_ACCESS_TOKEN_INVALID.create(api.getName(), I(account.getId()), I(session.getUserId()), I(session.getContextId()));
+            throw OAuthExceptionCodes.OAUTH_ACCESS_TOKEN_INVALID.create(api.getDisplayName(), I(account.getId()), I(session.getUserId()), I(session.getContextId()));
         }
 
         // Verify that scopes are available and enabled
